@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
-
+from ._version import __version__
+from .api import get, now, utcnow
 from .arrow import Arrow
 from .factory import ArrowFactory
-from .api import get, now, utcnow
-
-__version__ = '0.12.1'
-VERSION = __version__
+from .parser import ParserError
